
Development
===========

Theo by nature is just a "wrapper" project, and as such does not
change terribly often.  The underlying packages contain all the "good
stuff" and they change more frequently.

Rattail and Tailbone are the 2 main packages, responsible for the
"core" data layer, and web layer, respectively.

Usually there are also some POS integration packages involved; see
:ref:`pos-integration` for links to those.

Source code for *all* packages is hosted on the rattailproject.org
server, specifically under https://kallithea.rattailproject.org/

You can request an account there, and then "fork" anything as you
like.  Or skip the account and just clone whatever.  

Note that certain POS integration packages are "restricted" and not
available as part of the public project.  If you need access then
please send a request.
